@@ -68,7 +68,7 @@ export const subscriberPhonebook = {
 }
 
 let iscloudpbx = false
-let issppro = false
+let issppro = null
 const downloadsFolder = Cypress.config('downloadsFolder')
 const fixturesFolder = Cypress.config('fixturesFolder')
 
@@ -216,149 +216,149 @@ context('Subscriber details tests', () => {
                 cy.get('div[data-cy="aui-sound-file-upload--unavail"] [data-cy="file-select-button"]').should('be.visible')
             })
 
-            it('Check if invalid values are being rejected in Fax Features', () => {
-                cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
-                if (issppro) {
-                    cy.navigateMainMenu('settings / subscriber')
-                    cy.locationShouldBe('#/subscriber')
-                    searchInDataTable(subscriber.username)
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
-
-                    cy.get('div[data-cy="aui-detail-page-menu"]').contains('Fax Features').click()
-                    cy.get('[data-cy="destination-add"]').click()
-                    cy.get('input[data-cy="destination-email"]').type('notavalidemail')
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    cy.get('div[role="alert"]').should('have.class', 'bg-negative')
-                } else {
-                    cy.log('Not a SPPRO instance, exiting test...')
+            it('Check if invalid values are being rejected in Fax Features', function () {
+                if (!issppro) {
+                    cy.log('Not a SPPRO instance, skipping fax features tests...')
+                    this.skip()
                 }
+                cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
+                cy.navigateMainMenu('settings / subscriber')
+                cy.locationShouldBe('#/subscriber')
+                searchInDataTable(subscriber.username)
+                cy.get('div[class="aui-data-table"] .q-checkbox').click()
+                cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+                cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
+
+                cy.get('div[data-cy="aui-detail-page-menu"]').contains('Fax Features').click()
+                cy.get('[data-cy="destination-add"]').click()
+                cy.get('input[data-cy="destination-email"]').type('notavalidemail')
+                cy.get('[data-cy="aui-save-button"]').click()
+                cy.get('div[role="alert"]').should('have.class', 'bg-negative')
             })
 
-            it('Add/Delete Destination to Fax Features', () => {
-                cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
-                if (issppro) {
-                    cy.navigateMainMenu('settings / subscriber')
-                    cy.locationShouldBe('#/subscriber')
-                    searchInDataTable(subscriber.username)
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
-                    cy.get('div[data-cy="aui-detail-page-menu"]').contains('Fax Features').click()
-                    cy.get('[data-cy="faxserversettings-enable"]').click()
-                    cy.get('[data-cy="faxserversettings-t38"]').click()
-                    cy.get('[data-cy="faxserversettings-ecm"]').click()
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    cy.get('div[data-cy="faxserversettings-t38"][aria-disabled="true"]').should('not.exist')
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                    cy.get('[data-cy="destination-add"]').click()
-                    cy.get('input[data-cy="destination-email"]').type('test.mail@invalid.com')
-                    cy.get('label[data-cy="destination-filetype"]').click()
-                    cy.get('div[role="listbox"]').contains('TIFF').click()
-                    cy.get('[data-cy="destination-deliver-incoming"]').click()
-                    cy.get('[data-cy="destination-deliver-outgoing"]').click()
-                    cy.get('[data-cy="destination-receive-reports"]').click()
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    cy.get('div[data-cy="faxserversettings-t38"][aria-disabled="true"]').should('not.exist')
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                    cy.get('[data-cy="destination-add"]').click()
-                    cy.get('input[data-cy="destination-email"]:last').type('test.mail2@invalid.com')
-                    cy.get('label[data-cy="destination-filetype"]:last').click()
-                    cy.get('div[role="listbox"]').contains('TIFF').click()
-                    cy.get('[data-cy="destination-deliver-incoming"]:last').click()
-                    cy.get('[data-cy="destination-deliver-outgoing"]:last').click()
-                    cy.get('[data-cy="destination-receive-reports"]:last').click()
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    cy.get('div[data-cy="faxserversettings-t38"][aria-disabled="true"]').should('not.exist')
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                    cy.get('button[data-cy="destination-delete"]:last').click()
-                    cy.get('button[data-cy="destination-delete"]:last').click()
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    cy.get('div[data-cy="faxserversettings-t38"][aria-disabled="true"]').should('not.exist')
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                } else {
-                    cy.log('Not a SPPRO instance, exiting test...')
+            it('Add/Delete Destination to Fax Features', function () {
+                if (!issppro) {
+                    cy.log('Not a SPPRO instance, skipping fax features tests...')
+                    this.skip()
                 }
+                cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
+                cy.navigateMainMenu('settings / subscriber')
+                cy.locationShouldBe('#/subscriber')
+                searchInDataTable(subscriber.username)
+                cy.get('div[class="aui-data-table"] .q-checkbox').click()
+                cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+                cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
+                cy.get('div[data-cy="aui-detail-page-menu"]').contains('Fax Features').click()
+                cy.get('[data-cy="faxserversettings-enable"]').click()
+                cy.get('[data-cy="faxserversettings-t38"]').click()
+                cy.get('[data-cy="faxserversettings-ecm"]').click()
+                cy.get('[data-cy="aui-save-button"]').click()
+                cy.get('div[data-cy="faxserversettings-t38"][aria-disabled="true"]').should('not.exist')
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
+                cy.get('[data-cy="destination-add"]').click()
+                cy.get('input[data-cy="destination-email"]').type('test.mail@invalid.com')
+                cy.get('label[data-cy="destination-filetype"]').click()
+                cy.get('div[role="listbox"]').contains('TIFF').click()
+                cy.get('[data-cy="destination-deliver-incoming"]').click()
+                cy.get('[data-cy="destination-deliver-outgoing"]').click()
+                cy.get('[data-cy="destination-receive-reports"]').click()
+                cy.get('[data-cy="aui-save-button"]').click()
+                cy.get('div[data-cy="faxserversettings-t38"][aria-disabled="true"]').should('not.exist')
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
+                cy.get('[data-cy="destination-add"]').click()
+                cy.get('input[data-cy="destination-email"]:last').type('test.mail2@invalid.com')
+                cy.get('label[data-cy="destination-filetype"]:last').click()
+                cy.get('div[role="listbox"]').contains('TIFF').click()
+                cy.get('[data-cy="destination-deliver-incoming"]:last').click()
+                cy.get('[data-cy="destination-deliver-outgoing"]:last').click()
+                cy.get('[data-cy="destination-receive-reports"]:last').click()
+                cy.get('[data-cy="aui-save-button"]').click()
+                cy.get('div[data-cy="faxserversettings-t38"][aria-disabled="true"]').should('not.exist')
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
+                cy.get('button[data-cy="destination-delete"]:last').click()
+                cy.get('button[data-cy="destination-delete"]:last').click()
+                cy.get('[data-cy="aui-save-button"]').click()
+                cy.get('div[data-cy="faxserversettings-t38"][aria-disabled="true"]').should('not.exist')
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
             })
 
-            it('Add/Delete Secret Key Renew Notify Email to Fax Features', () => {
-                cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
-                if (issppro) {
-                    cy.navigateMainMenu('settings / subscriber')
-                    cy.locationShouldBe('#/subscriber')
-                    searchInDataTable(subscriber.username)
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
-                    cy.get('div[data-cy="aui-detail-page-menu"]').contains('Fax Features').click()
-                    cy.get('div[data-cy="mailtofax-enable"]').click()
-                    cy.get('input[data-cy="mailtofax-input-secret-key"]').type('testkey')
-                    cy.get('label[data-cy="mailtofax-secret-key-renew-interval"]').click()
-                    cy.get('div[role="listbox"]').contains('Monthly').click()
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    waitPageProgressAUI()
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                    cy.get('button[data-cy="secret-key-reniew-notify-add"]').click()
-                    cy.get('input[data-cy="secret-key-notify-email"]').type('test.mail@invalid.com')
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    waitPageProgressAUI()
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                    cy.get('button[data-cy="secret-key-reniew-notify-add"]').click()
-                    cy.get('input[data-cy="secret-key-notify-email"]:last').type('test.mail2@invalid.com')
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    waitPageProgressAUI()
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                    cy.get('button[data-cy="secret-key-reniew-notify-delete"]:last').click()
-                    cy.get('button[data-cy="secret-key-reniew-notify-delete"]').click()
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    waitPageProgressAUI()
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                } else {
-                    cy.log('Not a SPPRO instance, exiting test...')
+            it('Add/Delete Secret Key Renew Notify Email to Fax Features', function () {
+                if (!issppro) {
+                    cy.log('Not a SPPRO instance, skipping fax features tests...')
+                    this.skip()
                 }
+                cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
+                cy.navigateMainMenu('settings / subscriber')
+                cy.locationShouldBe('#/subscriber')
+                searchInDataTable(subscriber.username)
+                cy.get('div[class="aui-data-table"] .q-checkbox').click()
+                cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+                cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
+                cy.get('div[data-cy="aui-detail-page-menu"]').contains('Fax Features').click()
+                cy.get('div[data-cy="mailtofax-enable"]').click()
+                cy.get('input[data-cy="mailtofax-input-secret-key"]').type('testkey')
+                cy.get('label[data-cy="mailtofax-secret-key-renew-interval"]').click()
+                cy.get('div[role="listbox"]').contains('Monthly').click()
+                cy.get('[data-cy="aui-save-button"]').click()
+                waitPageProgressAUI()
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
+                cy.get('button[data-cy="secret-key-reniew-notify-add"]').click()
+                cy.get('input[data-cy="secret-key-notify-email"]').type('test.mail@invalid.com')
+                cy.get('[data-cy="aui-save-button"]').click()
+                waitPageProgressAUI()
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
+                cy.get('button[data-cy="secret-key-reniew-notify-add"]').click()
+                cy.get('input[data-cy="secret-key-notify-email"]:last').type('test.mail2@invalid.com')
+                cy.get('[data-cy="aui-save-button"]').click()
+                waitPageProgressAUI()
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
+                cy.get('button[data-cy="secret-key-reniew-notify-delete"]:last').click()
+                cy.get('button[data-cy="secret-key-reniew-notify-delete"]').click()
+                cy.get('[data-cy="aui-save-button"]').click()
+                waitPageProgressAUI()
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
             })
 
-            it('Add/Delete ACL to Fax Features', () => {
-                cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
-                if (issppro) {
-                    cy.navigateMainMenu('settings / subscriber')
-                    cy.locationShouldBe('#/subscriber')
-                    searchInDataTable(subscriber.username)
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
-                    cy.get('div[data-cy="aui-detail-page-menu"]').contains('Fax Features').click()
-                    cy.get('button[data-cy="acl-add"]').scrollIntoView()
-                    cy.get('button[data-cy="acl-add"]').click({ force: true })
-                    cy.get('label[data-cy="acl-from-email"]').type('test.mail@test.com')
-                    cy.get('input[data-cy="acl-received-from-ip"]').type('10.0.0.10')
-                    cy.get('input[data-cy="acl-destination"]').type('0123456789')
-                    cy.get('div[data-cy="acl-regex-enable"]').click()
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    waitPageProgressAUI()
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                    cy.get('button[data-cy="acl-add"]').scrollIntoView()
-                    cy.get('button[data-cy="acl-add"]').click({ force: true })
-                    cy.get('label[data-cy="acl-from-email"]:last').type('test.mail2@test.com')
-                    cy.get('input[data-cy="acl-received-from-ip"]:last').type('10.0.0.11')
-                    cy.get('input[data-cy="acl-destination"]:last').type('012345678')
-                    cy.get('div[data-cy="acl-regex-enable"]:last').click()
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    waitPageProgressAUI()
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                    cy.get('button[data-cy="acl-delete"]:last').click()
-                    cy.get('button[data-cy="acl-delete"]').click()
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    waitPageProgressAUI()
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                } else {
-                    cy.log('Not a SPPRO instance, exiting test...')
+            it('Add/Delete ACL to Fax Features', function () {
+                if (!issppro) {
+                    cy.log('Not a SPPRO instance, skipping fax features tests...')
+                    this.skip()
                 }
+                cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
+                cy.navigateMainMenu('settings / subscriber')
+                cy.locationShouldBe('#/subscriber')
+                searchInDataTable(subscriber.username)
+                cy.get('div[class="aui-data-table"] .q-checkbox').click()
+                cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+                cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
+                cy.get('div[data-cy="aui-detail-page-menu"]').contains('Fax Features').click()
+                cy.get('button[data-cy="acl-add"]').scrollIntoView()
+                cy.get('button[data-cy="acl-add"]').click({ force: true })
+                cy.get('label[data-cy="acl-from-email"]').type('test.mail@test.com')
+                cy.get('input[data-cy="acl-received-from-ip"]').type('10.0.0.10')
+                cy.get('input[data-cy="acl-destination"]').type('0123456789')
+                cy.get('div[data-cy="acl-regex-enable"]').click()
+                cy.get('[data-cy="aui-save-button"]').click()
+                waitPageProgressAUI()
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
+                cy.get('button[data-cy="acl-add"]').scrollIntoView()
+                cy.get('button[data-cy="acl-add"]').click({ force: true })
+                cy.get('label[data-cy="acl-from-email"]:last').type('test.mail2@test.com')
+                cy.get('input[data-cy="acl-received-from-ip"]:last').type('10.0.0.11')
+                cy.get('input[data-cy="acl-destination"]:last').type('012345678')
+                cy.get('div[data-cy="acl-regex-enable"]:last').click()
+                cy.get('[data-cy="aui-save-button"]').click()
+                waitPageProgressAUI()
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
+                cy.get('button[data-cy="acl-delete"]:last').click()
+                cy.get('button[data-cy="acl-delete"]').click()
+                cy.get('[data-cy="aui-save-button"]').click()
+                waitPageProgressAUI()
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
             })
         })
 
-        context('Location mappings', () => {    
+        context('Location mappings', () => {
             it('Add Location Mapping', () => {
                 apiLoginAsSuperuser().then(authHeader => {
                     apiRemoveLocationMappingBy({ external_id: locationmapping.external_id, authHeader })
@@ -430,92 +430,92 @@ context('Subscriber details tests', () => {
         })
 
         context('Phonebook', () => {
-            it('Try to create phonebook entry with invalid values', () => {
-                if (issppro) {
-                    cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
-                    cy.navigateMainMenu('settings / subscriber')
-
-                    cy.locationShouldBe('#/subscriber')
-                    searchInDataTable(subscriber.username)
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
-                    cy.get('div[data-cy="aui-detail-page-menu"] div').contains('Phonebook').click()
-                    cy.get('a[data-cy="aui-list-action--add"]').click()
-                    cy.get('button[data-cy="aui-save-button"]').click()
-                    cy.get('label[data-cy="phonebook-name"]').find('div[role="alert"]').contains('Input is required').should('be.visible')
-                    cy.get('label[data-cy="phonebook-number"]').find('div[role="alert"]').contains('Input is required').should('be.visible')
-                } else {
-                    cy.log("Instance is CE, not PRO. Skipping phonebook tests...")
+            it('Try to create phonebook entry with invalid values', function () {
+                if (!issppro) {
+                    cy.log('Not a SPPRO instance, skipping phonebook tests...')
+                    this.skip()
                 }
+                cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
+                cy.navigateMainMenu('settings / subscriber')
+
+                cy.locationShouldBe('#/subscriber')
+                searchInDataTable(subscriber.username)
+                cy.get('div[class="aui-data-table"] .q-checkbox').click()
+                cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+                cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
+                cy.get('div[data-cy="aui-detail-page-menu"] div').contains('Phonebook').click()
+                cy.get('a[data-cy="aui-list-action--add"]').click()
+                cy.get('button[data-cy="aui-save-button"]').click()
+                cy.get('label[data-cy="phonebook-name"]').find('div[role="alert"]').contains('Input is required').should('be.visible')
+                cy.get('label[data-cy="phonebook-number"]').find('div[role="alert"]').contains('Input is required').should('be.visible')
             })
 
-            it('Create a phonebook', () => {
-                if (issppro) {
-                    apiLoginAsSuperuser().then(authHeader => {
-                        apiRemoveSubscriberPhonebookBy({ name: subscriberPhonebook.name, authHeader })
-                    })
-                    cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
-                    cy.navigateMainMenu('settings / subscriber')
-
-                    cy.locationShouldBe('#/subscriber')
-                    searchInDataTable(subscriber.username)
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
-                    cy.get('div[data-cy="aui-detail-page-menu"] div').contains('Phonebook').click()
-                    cy.get('a[data-cy="aui-list-action--add"]').click()
-                    cy.get('input[data-cy="phonebook-name"]').type(subscriberPhonebook.name)
-                    cy.get('input[data-cy="phonebook-number"]').type(subscriberPhonebook.number)
-                    cy.get('button[data-cy="aui-save-button"]').click()
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                    cy.get('td[data-cy="q-td--name"]').contains(subscriberPhonebook.name).should('be.visible')
-                    cy.get('td[data-cy="q-td--number"]').contains(subscriberPhonebook.number).should('be.visible')
-                } else {
-                    cy.log("Instance is CE, not PRO. Skipping phonebook tests...")
+            it('Create a phonebook', function () {
+                if (!issppro) {
+                    cy.log('Not a SPPRO instance, skipping phonebook tests...')
+                    this.skip()
                 }
+                apiLoginAsSuperuser().then(authHeader => {
+                    apiRemoveSubscriberPhonebookBy({ name: subscriberPhonebook.name, authHeader })
+                })
+                cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
+                cy.navigateMainMenu('settings / subscriber')
+
+                cy.locationShouldBe('#/subscriber')
+                searchInDataTable(subscriber.username)
+                cy.get('div[class="aui-data-table"] .q-checkbox').click()
+                cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+                cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
+                cy.get('div[data-cy="aui-detail-page-menu"] div').contains('Phonebook').click()
+                cy.get('a[data-cy="aui-list-action--add"]').click()
+                cy.get('input[data-cy="phonebook-name"]').type(subscriberPhonebook.name)
+                cy.get('input[data-cy="phonebook-number"]').type(subscriberPhonebook.number)
+                cy.get('button[data-cy="aui-save-button"]').click()
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
+                cy.get('td[data-cy="q-td--name"]').contains(subscriberPhonebook.name).should('be.visible')
+                cy.get('td[data-cy="q-td--number"]').contains(subscriberPhonebook.number).should('be.visible')
             })
 
-            it('Edit a phonebook', () => {
-                if (issppro) {
-                    cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
-                    cy.navigateMainMenu('settings / subscriber')
-
-                    cy.locationShouldBe('#/subscriber')
-                    searchInDataTable(subscriber.username)
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
-                    cy.get('div[data-cy="aui-detail-page-menu"] div').contains('Phonebook').click()
-                    searchInDataTable(subscriberPhonebook.name, 'Name')
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetailsPhonebookEntryEdit"]').click()
-                    cy.get('input[data-cy="phonebook-number"]').clear().type('anothertestnumber')
-                    cy.get('button[data-cy="aui-save-button"]').click()
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                    cy.get('[data-cy="aui-close-button"]').click()
-                    cy.get('td[data-cy="q-td--number"]').contains('anothertestnumber').should('be.visible')
-                } else {
-                    cy.log("Instance is CE, not PRO. Skipping phonebook tests...")
+            it('Edit a phonebook', function () {
+                if (!issppro) {
+                    cy.log('Not a SPPRO instance, skipping phonebook tests...')
+                    this.skip()
                 }
+                cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
+                cy.navigateMainMenu('settings / subscriber')
+
+                cy.locationShouldBe('#/subscriber')
+                searchInDataTable(subscriber.username)
+                cy.get('div[class="aui-data-table"] .q-checkbox').click()
+                cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+                cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
+                cy.get('div[data-cy="aui-detail-page-menu"] div').contains('Phonebook').click()
+                searchInDataTable(subscriberPhonebook.name, 'Name')
+                cy.get('div[class="aui-data-table"] .q-checkbox').click()
+                cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+                cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetailsPhonebookEntryEdit"]').click()
+                cy.get('input[data-cy="phonebook-number"]').clear().type('anothertestnumber')
+                cy.get('button[data-cy="aui-save-button"]').click()
+                cy.get('div[role="alert"]').should('have.class', 'bg-positive')
+                cy.get('[data-cy="aui-close-button"]').click()
+                cy.get('td[data-cy="q-td--number"]').contains('anothertestnumber').should('be.visible')
             })
 
-            it('Delete a phonebook', () => {
-                if (issppro) {
-                    cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
-                    cy.navigateMainMenu('settings / subscriber')
-
-                    cy.locationShouldBe('#/subscriber')
-                    searchInDataTable(subscriber.username)
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
-                    cy.get('div[data-cy="aui-detail-page-menu"] div').contains('Phonebook').click()
-                    deleteItemOnListPageBy(subscriberPhonebook.name, 'Name')
-                } else {
-                    cy.log("Instance is CE, not PRO. Skipping phonebook tests...")
+            it('Delete a phonebook', function () {
+                if (!issppro) {
+                    cy.log('Not a SPPRO instance, skipping phonebook tests...')
+                    this.skip()
                 }
+                cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
+                cy.navigateMainMenu('settings / subscriber')
+
+                cy.locationShouldBe('#/subscriber')
+                searchInDataTable(subscriber.username)
+                cy.get('div[class="aui-data-table"] .q-checkbox').click()
+                cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+                cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
+                cy.get('div[data-cy="aui-detail-page-menu"] div').contains('Phonebook').click()
+                deleteItemOnListPageBy(subscriberPhonebook.name, 'Name')
             })
         })
     })
