@@ -19,6 +19,7 @@ import {
 } from '../../../support/e2e'
 
 const ngcpConfig = Cypress.config('ngcpConfig')
+let issppro = null
 
 export const customer = {
     billing_profile_definition: 'id',
@@ -104,6 +105,12 @@ context('Subscriber tests', () => {
     context('UI subscriber tests', () => {
         before(() => {
             Cypress.log({ displayName: 'API URL', message: ngcpConfig.apiHost })
+            cy.intercept('GET', '**/api/platforminfo/').as('platforminfo')
+            cy.reload()
+            cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
+            cy.wait('@platforminfo').then(({ response }) => {
+                issppro = response.body.type === 'sppro'
+            })
             apiLoginAsSuperuser().then(authHeader => {
                 Cypress.log({ displayName: 'INIT', message: 'Preparing environment...'})
                 cy.log('Preparing environment...')
@@ -251,106 +258,96 @@ context('Subscriber tests', () => {
             cy.get('div[role="alert"]').should('have.class', 'bg-positive')
         })
 
-        it('Edit Pilot Subscriber Master Data', () => {
-            cy.intercept('GET', '**/api/platforminfo/').as('platforminfo')
-            cy.reload()
+        it('Edit Pilot Subscriber Master Data', function () {
+            if (!issppro) {
+                cy.log('Not a SPPRO instance, skipping pilot subscriber tests...')
+                this.skip()
+            }
             cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
-            cy.wait('@platforminfo').then(({ response }) => {
-                if (response.body.type === 'sppro') {
-                    cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
-                    cy.navigateMainMenu('settings / customer')
+            cy.navigateMainMenu('settings / customer')
 
-                    cy.locationShouldBe('#/customer')
-                    searchInDataTable(customerPbx.external_id, 'External #')
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--customerDetailsSubscribers"]').click()
-                    waitPageProgressAUI()
+            cy.locationShouldBe('#/customer')
+            searchInDataTable(customerPbx.external_id, 'External #')
+            cy.get('div[class="aui-data-table"] .q-checkbox').click()
+            cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+            cy.get('a[data-cy="aui-data-table-row-menu--customerDetailsSubscribers"]').click()
+            waitPageProgressAUI()
 
-                    searchInDataTable(pilotSubscriber.external_id, 'Subscriber External ID')
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
-                    waitPageProgressAUI()
+            searchInDataTable(pilotSubscriber.external_id, 'Subscriber External ID')
+            cy.get('div[class="aui-data-table"] .q-checkbox').click()
+            cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+            cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
+            waitPageProgressAUI()
 
-                    cy.get('a[data-cy="aui-edit-button"]').click()
-                    cy.get('label[data-cy="aui-input-subscriber-username"] input').type(pilotSubscriber.external_id)
-                    cy.get('input[data-cy="subscriber-email"]').clear()
-                    cy.get('input[data-cy="subscriber-email"]').type('newtest@mail.com')
-                    cy.get('input[data-cy="subscriber-web-username"]').clear()
-                    cy.get('input[data-cy="subscriber-web-username"]').type(pilotSubscriber.external_id)
-                    cy.get('input[data-cy="subscriber-web-password"]').type(pilotSubscriber.password)
-                    cy.qSelect({ dataCy: 'aui-selection-lock-level', itemContains: 'Global' })
-                    cy.qSelect({ dataCy: 'subscriber-status', itemContains: 'Locked' })
-                    cy.get('label[data-cy="aui-selection-timezone"] input').type('Europe/Vienna')
-                    cy.get('div[role="listbox"]').should('be.visible')
-                    cy.wait(1000)
-                    cy.get('div[role="listbox"]').click()
-                    cy.get('label[data-cy="aui-select-profile-set"] input').type(profileSet.name)
-                    cy.get('div[role="listbox"]').should('be.visible')
-                    cy.wait(1000)
-                    cy.get('div[role="listbox"]').click()
-                    cy.get('label[data-cy="aui-select-profile"] input').click()
-                    cy.get('div[role="listbox"]').should('be.visible')
-                    cy.wait(1000)
-                    cy.get('div[role="listbox"]').click()
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                } else {
-                    cy.log('Not a SPPRO instance, exiting test...')
-                }
-            })
+            cy.get('a[data-cy="aui-edit-button"]').click()
+            cy.get('label[data-cy="aui-input-subscriber-username"] input').type(pilotSubscriber.external_id)
+            cy.get('input[data-cy="subscriber-email"]').clear()
+            cy.get('input[data-cy="subscriber-email"]').type('newtest@mail.com')
+            cy.get('input[data-cy="subscriber-web-username"]').clear()
+            cy.get('input[data-cy="subscriber-web-username"]').type(pilotSubscriber.external_id)
+            cy.get('input[data-cy="subscriber-web-password"]').type(pilotSubscriber.password)
+            cy.qSelect({ dataCy: 'aui-selection-lock-level', itemContains: 'Global' })
+            cy.qSelect({ dataCy: 'subscriber-status', itemContains: 'Locked' })
+            cy.get('label[data-cy="aui-selection-timezone"] input').type('Europe/Vienna')
+            cy.get('div[role="listbox"]').should('be.visible')
+            cy.wait(1000)
+            cy.get('div[role="listbox"]').click()
+            cy.get('label[data-cy="aui-select-profile-set"] input').type(profileSet.name)
+            cy.get('div[role="listbox"]').should('be.visible')
+            cy.wait(1000)
+            cy.get('div[role="listbox"]').click()
+            cy.get('label[data-cy="aui-select-profile"] input').click()
+            cy.get('div[role="listbox"]').should('be.visible')
+            cy.wait(1000)
+            cy.get('div[role="listbox"]').click()
+            cy.get('[data-cy="aui-save-button"]').click()
+            cy.get('div[role="alert"]').should('have.class', 'bg-positive')
         })
 
-        it('Edit Seat Subscriber Master Data', () => {
-            cy.intercept('GET', '**/api/platforminfo/').as('platforminfo')
-            cy.reload()
+        it('Edit Seat Subscriber Master Data', function () {
+            if (!issppro) {
+                cy.log('Not a SPPRO instance, skipping seat subscriber tests...')
+                this.skip()
+            }
             cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
-            cy.wait('@platforminfo').then(({ response }) => {
-                if (response.body.type === 'sppro') {
-                    cy.quickLogin(ngcpConfig.username, ngcpConfig.password)
-                    cy.navigateMainMenu('settings / customer')
+            cy.navigateMainMenu('settings / customer')
 
-                    cy.locationShouldBe('#/customer')
-                    searchInDataTable(customerPbx.external_id, 'External #')
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--customerDetailsSubscribers"]').click()
-                    waitPageProgressAUI()
+            cy.locationShouldBe('#/customer')
+            searchInDataTable(customerPbx.external_id, 'External #')
+            cy.get('div[class="aui-data-table"] .q-checkbox').click()
+            cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+            cy.get('a[data-cy="aui-data-table-row-menu--customerDetailsSubscribers"]').click()
+            waitPageProgressAUI()
 
-                    searchInDataTable(seatSubscriber.external_id, 'Subscriber External ID')
-                    cy.get('div[class="aui-data-table"] .q-checkbox').click()
-                    cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
-                    cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
-                    waitPageProgressAUI()
+            searchInDataTable(seatSubscriber.external_id, 'Subscriber External ID')
+            cy.get('div[class="aui-data-table"] .q-checkbox').click()
+            cy.get('button[data-cy="aui-list-action--edit-menu-btn"]').click()
+            cy.get('a[data-cy="aui-data-table-row-menu--subscriberDetails"]').click()
+            waitPageProgressAUI()
 
-                    cy.get('a[data-cy="aui-edit-button"]').click()
-                    cy.get('label[data-cy="aui-input-subscriber-username"] input').type(seatSubscriber.external_id)
-                    cy.get('input[data-cy="subscriber-email"]').clear()
-                    cy.get('input[data-cy="subscriber-email"]').type('newtest@mail.com')
-                    cy.get('input[data-cy="subscriber-web-username"]').clear()
-                    cy.get('input[data-cy="subscriber-web-username"]').type(seatSubscriber.external_id)
-                    cy.get('input[data-cy="subscriber-web-password"]').type(seatSubscriber.password)
-                    cy.qSelect({ dataCy: 'aui-selection-lock-level', itemContains: 'Global' })
-                    cy.qSelect({ dataCy: 'subscriber-status', itemContains: 'Locked' })
-                    cy.get('label[data-cy="aui-selection-timezone"] input').type('Europe/Vienna')
-                    cy.get('div[role="listbox"]').should('be.visible')
-                    cy.wait(1000)
-                    cy.get('div[role="listbox"]').click()
-                    cy.get('label[data-cy="aui-select-profile-set"] input').type(profileSet.name)
-                    cy.get('div[role="listbox"]').should('be.visible')
-                    cy.wait(1000)
-                    cy.get('div[role="listbox"]').click()
-                    cy.get('label[data-cy="aui-select-profile"] input').click()
-                    cy.get('div[role="listbox"]').should('be.visible')
-                    cy.wait(1000)
-                    cy.get('div[role="listbox"]').click()
-                    cy.get('[data-cy="aui-save-button"]').click()
-                    cy.get('div[role="alert"]').should('have.class', 'bg-positive')
-                } else {
-                    cy.log('Not a SPPRO instance, exiting test...')
-                }
-            })
+            cy.get('a[data-cy="aui-edit-button"]').click()
+            cy.get('label[data-cy="aui-input-subscriber-username"] input').type(seatSubscriber.external_id)
+            cy.get('input[data-cy="subscriber-email"]').clear()
+            cy.get('input[data-cy="subscriber-email"]').type('newtest@mail.com')
+            cy.get('input[data-cy="subscriber-web-username"]').clear()
+            cy.get('input[data-cy="subscriber-web-username"]').type(seatSubscriber.external_id)
+            cy.get('input[data-cy="subscriber-web-password"]').type(seatSubscriber.password)
+            cy.qSelect({ dataCy: 'aui-selection-lock-level', itemContains: 'Global' })
+            cy.qSelect({ dataCy: 'subscriber-status', itemContains: 'Locked' })
+            cy.get('label[data-cy="aui-selection-timezone"] input').type('Europe/Vienna')
+            cy.get('div[role="listbox"]').should('be.visible')
+            cy.wait(1000)
+            cy.get('div[role="listbox"]').click()
+            cy.get('label[data-cy="aui-select-profile-set"] input').type(profileSet.name)
+            cy.get('div[role="listbox"]').should('be.visible')
+            cy.wait(1000)
+            cy.get('div[role="listbox"]').click()
+            cy.get('label[data-cy="aui-select-profile"] input').click()
+            cy.get('div[role="listbox"]').should('be.visible')
+            cy.wait(1000)
+            cy.get('div[role="listbox"]').click()
+            cy.get('[data-cy="aui-save-button"]').click()
+            cy.get('div[role="alert"]').should('have.class', 'bg-positive')
         })
 
         it('Delete subscriber and check if they are deleted', () => {
